#  RW Foundations
# ================
# ______
# -The RW Foundational Libraries

# Filename: ./README.md
# -General comments for the overall project (building, dependencies, etc.)

#    --=^=--

# ==============
# Recommended - BUILDING WITH MESON (in a terminal from project's base directory):
#
# -First, initialize the project as a meson build one (needed one-time only):
#
#     meson setup build
#
# -Build, then execute:
#
#     meson compile -C build
#
#     build/<program_name>
#
# NOTE:
# -replace '<program_name>' with (eg), 'sumomos_world', 'pageone', 'pandora'
#
# NOTE:
# -You can set meson project configuration settings any time, but you should 
#   perform the operation within the project's build dir, not the code dir. EG:
#
#     cd build && meson configure -Dbuildtype=release && cd ..
#
#   executed from the terminal would ensure the project is built in release mode.
#
# ==============

#    --=^=--

# ==============
# BUILDING WITH GCC instead (in a terminal from project's base directory):
#
# -Build, then execute (in the example case of 'pageone'):
#
#     g++ main_pageone.cpp src/srcs_all.cpp \
#         -flto \
#         -lcurl \
#         -Iinclude/ -Iextern/ \
#         -std=c++17 -O3 -o pageone
#     ./pageone
#
# ==============

#    --=^=--

# ==============
# DEPENDENCIES:
#
# There are external dependencies that you won't need to install on your system
#   (already included in the project's codetree under the './extern/' directory):
#
# - JSON for Modern C++  (tentative)
#     https://github.com/nlohmann/json
#
# There are external dependencies that you _will_ need to install on your system
#   as well. Here are the sources of the 'not-built-in' external dependencies
#   that you'll need to install first. Generally, these are provided by your
#   system's (or some other) package manager. But if not you can always clone
#   the repos and build them locally (often a good choice anyway, perf-wise):
#
# - FLTK
#     https://www.fltk.org/
# - curl
#     https://curl.haxx.se/
#
# And while not a requirement per se, Meson Build is highly recommended (it will
#   also need to be installed separately):
#
# - The Meson Build System
#     https://mesonbuild.com/
#
# NOTE: If you ever get stuck on any of this Anon, just make a post asking for
#   help up on the /robowaifu/ board itself. Some anon there might help you out.
#
# ==============

#    --=^=--

# ==============
# SEE ALSO:
#
# https://stroustrup.com/programming.html
# https://en.cppreference.com/w/cpp/language/basic_concepts
# https://www.fltk.org/doc-1.3/intro.html
# https://mesonbuild.com/Reference-manual.html
#
# https://json.nlohmann.me/  (tentative)
#
# ==============


#    --=^=--

# "So is it true Sempai? Are robowaifus really better than any human woman?"

# rw_foundations_lib.v221022
# Copyright (2022)
# License MIT (Expat) https://opensource.org/licenses/MIT
